==> material-ui-shell-1.1.10.tgz: package/es/providers/Filter/fields/text.js <==
import React from 'react';
import TextField from '@material-ui/core/TextField';
import InputAdornment from '@material-ui/core/InputAdornment';
import IconButton from '@material-ui/core/IconButton';
import FormatSize from '@material-ui/icons/FormatSize';
import Title from '@material-ui/icons/Title';
var field = {
  operators: [{
    value: '=',
    label: '='
  }, {
    value: '>',
    label: '>'
  }, {
    value: '<',
    label: '<'
  }, {
    value: '!=',
    label: '!='
  }, {
    value: '<=',
    label: '<='
  }, {
    value: '>=',
    label: '>='
  }, {
    value: 'like',
    label: 'like'
  }, {
    value: '!like',
    label: '!like'
  }],
  defaultOperator: 'like',
  filter: function filter(rawValue, q) {
    var operator = q.operator,
        qv = q.value,
        _q$isCaseSensitive = q.isCaseSensitive,
        isCaseSensitive = _q$isCaseSensitive === void 0 ? false : _q$isCaseSensitive;

    if (qv !== '') {
      var queryValue = isCaseSensitive ? qv : qv.toUpperCase();
      var value = isCaseSensitive ? rawValue : rawValue.toUpperCase();

      switch (operator) {
        case '=':
          return value === queryValue;

        case '>':
          return value.localeCompare(queryValue) > 0;

        case '<':
          return value.localeCompare(queryValue) < 0;

        case '!=':
          return value !== queryValue;

        case '<=':
          return value.localeCompare(queryValue) <= 0;

        case '>=':
          return value.localeCompare(queryValue) >= 0;

        case 'like':
          return value.indexOf(queryValue) !== -1;

        case '!like':
          return value.indexOf(queryValue) === -1;

        default:
          return false;
      }
    } else {
      return true;
    }
  },
  sort: function sort(orientation, a, b) {
    var result = a < b ? -1 : a > b ? 1 : 0;
    return result * orientation;
  },
  render: function render(_ref, _onChange) {
    var _ref$value = _ref.value,
        value = _ref$value === void 0 ? '' : _ref$value,
        _ref$isCaseSensitive = _ref.isCaseSensitive,
        isCaseSensitive = _ref$isCaseSensitive === void 0 ? false : _ref$isCaseSensitive;
    return /*#__PURE__*/React.createElement(TextField, {
      variant: "outlined",
      style: {
        padding: 1
      },
      type: "text",
      value: value,
      fullWidth: true,
      onChange: function onChange(e) {
        return _onChange({
          value: e.target.value
        });
      },
      InputProps: {
        endAdornment: /*#__PURE__*/React.createElement(InputAdornment, {
          position: "end"
        }, /*#__PURE__*/React.createElement(IconButton, {
          color: isCaseSensitive ? 'secondary' : 'primary',
          onClick: function onClick() {
            return _onChange({
              isCaseSensitive: !isCaseSensitive
            });
          }
        }, /*#__PURE__*/React.createElement(FormatSize, null)))
      }
    });
  }
};
export default field;

==> material-ui-shell-1.1.12.tgz: package/es/providers/Filter/fields/text.js <==
import React from 'react';
import TextField from '@material-ui/core/TextField';
import InputAdornment from '@material-ui/core/InputAdornment';
import IconButton from '@material-ui/core/IconButton';
import FormatSize from '@material-ui/icons/FormatSize';
import Title from '@material-ui/icons/Title';
var field = {
  operators: [{
    value: '=',
    label: '='
  }, {
    value: '>',
    label: '>'
  }, {
    value: '<',
    label: '<'
  }, {
    value: '!=',
    label: '!='
  }, {
    value: '<=',
    label: '<='
  }, {
    value: '>=',
    label: '>='
  }, {
    value: 'like',
    label: 'like'
  }, {
    value: '!like',
    label: '!like'
  }],
  defaultOperator: 'like',
  filter: function filter(rawValue, q) {
    var operator = q.operator,
        qv = q.value,
        _q$isCaseSensitive = q.isCaseSensitive,
        isCaseSensitive = _q$isCaseSensitive === void 0 ? false : _q$isCaseSensitive;

    if (qv !== '') {
      var queryValue = qv;
      var value = rawValue;

      if (isCaseSensitive) {
        queryValue = qv != null ? qv.toUpperCase() : qv;
        value = value != null ? value.toUpperCase() : qv;
      }

      switch (operator) {
        case '=':
          return value === queryValue;

        case '>':
          return value.localeCompare(queryValue) > 0;

        case '<':
          return value.localeCompare(queryValue) < 0;

        case '!=':
          return value !== queryValue;

        case '<=':
          return value.localeCompare(queryValue) <= 0;

        case '>=':
          return value.localeCompare(queryValue) >= 0;

        case 'like':
          return value.indexOf(queryValue) !== -1;

        case '!like':
          return value.indexOf(queryValue) === -1;

        default:
          return false;
      }
    } else {
      return true;
    }
  },
  sort: function sort(orientation, a, b) {
    var result = a < b ? -1 : a > b ? 1 : 0;
    return result * orientation;
  },
  render: function render(_ref, _onChange) {
    var _ref$value = _ref.value,
        value = _ref$value === void 0 ? '' : _ref$value,
        _ref$isCaseSensitive = _ref.isCaseSensitive,
        isCaseSensitive = _ref$isCaseSensitive === void 0 ? false : _ref$isCaseSensitive;
    return /*#__PURE__*/React.createElement(TextField, {
      variant: "outlined",
      style: {
        padding: 1
      },
      type: "text",
      value: value,
      fullWidth: true,
      onChange: function onChange(e) {
        return _onChange({
          value: e.target.value
        });
      },
      InputProps: {
        endAdornment: /*#__PURE__*/React.createElement(InputAdornment, {
          position: "end"
        }, /*#__PURE__*/React.createElement(IconButton, {
          color: isCaseSensitive ? 'secondary' : 'primary',
          onClick: function onClick() {
            return _onChange({
              isCaseSensitive: !isCaseSensitive
            });
          }
        }, /*#__PURE__*/React.createElement(FormatSize, null)))
      }
    });
  }
};
export default field;
